@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-recomplete
-;; Package-Version: 20251214.1150
-;; Package-Revision: be53d7b0c573
+;; Package-Version: 20260108.1321
+;; Package-Revision: d580e7f0bdf8
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -74,8 +74,8 @@
 ;; - This is set to nil via `recomplete--alist-clear-hook' when incompatible functions run.
 ;;
 ;; Keys are:
-;; - `buffer-undo-list': The undo state before execution.
-;; - `pending-undo-list': The undo state before execution.
+;; - `buffer-undo-list': The buffer-undo-list before execution.
+;; - `pending-undo-list': The pending-undo-list before execution.
 ;; - `point' The point before execution.
 ;; - `msg-text' The message text displayed to the user.
 ;; - `cycle-index' The position in the list of options to cycle through.
@@ -96,7 +96,7 @@
 (defmacro recomplete--with-advice (advice &rest body)
   "Execute BODY with ADVICE temporarily enabled.
 
-Advice are triplets of (SYMBOL HOW FUNCTION),
+Each advice is a triplet of (SYMBOL HOW FUNCTION),
 see `advice-add' documentation."
   (declare (indent 1))
   (let ((advice-list advice)
@@ -178,7 +178,7 @@ see `advice-add' documentation."
 (defun recomplete--undo-next (list)
   "Get the next undo step in LIST.
 
-Argument LIST compatible list `buffer-undo-list'."
+Argument LIST is a `buffer-undo-list' compatible list."
   (declare (important-return-value t))
   (while (car list)
     (setq list (cdr list)))
